@@ -17,6 +17,7 @@ from biosimulators_utils.sedml import validation
 from biosimulators_utils.sedml.data_model import (Task, ModelLanguage, ModelAttributeChange,  # noqa: F401
                                                   UniformTimeCourseSimulation, Variable)
 from biosimulators_utils.sedml.exec import exec_sed_doc
+from biosimulators_utils.utils.core import raise_errors_warnings
 from rpy2.robjects.vectors import StrVector
 import functools
 import numpy
@@ -78,19 +79,31 @@ def exec_sed_task(task, variables, log=None):
     log = log or TaskLog()
 
     # validate task
-    validation.validate_task(task)
-    validation.validate_model_language(task.model.language, ModelLanguage.SBML)
-    validation.validate_model_change_types(task.model.changes, ())
-    validation.validate_model_changes(task.model.changes)
-    validation.validate_simulation_type(task.simulation, (UniformTimeCourseSimulation, ))
-    validate_time_course(task.simulation)
-    validation.validate_uniform_time_course_simulation(task.simulation)
-    validation.validate_data_generator_variables(variables)
+    model = task.model
+    sim = task.simulation
+
+    raise_errors_warnings(validation.validate_task(task),
+                          error_summary='Task `{}` is invalid.'.format(task.id))
+    raise_errors_warnings(validation.validate_model_language(task.model.language, ModelLanguage.SBML),
+                          error_summary='Language for model `{}` is not supported.'.format(model.id))
+    raise_errors_warnings(validation.validate_model_change_types(task.model.changes, ()),
+                          error_summary='Changes for model `{}` are not supported.'.format(model.id))
+    raise_errors_warnings(validation.validate_model_changes(task.model),
+                          error_summary='Changes for model `{}` are invalid.'.format(model.id))
+    raise_errors_warnings(validation.validate_simulation_type(task.simulation, (UniformTimeCourseSimulation, )),
+                          error_summary='{} `{}` is not supported.'.format(sim.__class__.__name__, sim.id))
+    raise_errors_warnings(validation.validate_simulation(task.simulation),
+                          error_summary='Simulation `{}` is invalid.'.format(sim.id))
+    raise_errors_warnings(validate_time_course(task.simulation),
+                          error_summary='Simulation `{}` is invalid.'.format(sim.id))
+    raise_errors_warnings(validation.validate_data_generator_variables(variables),
+                          error_summary='Data generator variables for task `{}` are invalid.'.format(task.id))
     target_x_paths_keys = get_variable_target_x_path_keys(variables, task.model.source)
 
     # validate model
-    validation.validate_model(task.model.source, ModelLanguage.SBML,
-                              name='`{}` for task `{}`'.format(task.model.id, task.id))
+    raise_errors_warnings(*validation.validate_model(task.model, [], working_dir='.'),
+                          error_summary='Model `{}` is invalid.'.format(model.id),
+                          warning_summary='Model `{}` may be invalid.'.format(model.id))
 
     # get BoolNet
     boolnet = get_boolnet()
